package org.communiquons.dccaggregator.activities

import android.content.Intent
import android.os.Bundle
import android.view.Menu
import android.view.MenuItem
import androidx.appcompat.app.AppCompatDelegate
import com.google.zxing.BarcodeFormat
import com.journeyapps.barcodescanner.BarcodeEncoder
import org.communiquons.dccaggregator.R
import org.communiquons.dccaggregator.databinding.ActivityMainBinding
import org.communiquons.dccaggregator.ext.toDimensSize

class MainActivity : BaseActivity() {
    private lateinit var binding: ActivityMainBinding

    private val qrSize by lazy {
        R.dimen.qr_code_fullscreen_size.toDimensSize(this).toInt()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setTheme(R.style.Theme_DCCAggregator)

        binding = ActivityMainBinding.inflate(layoutInflater)
        setContentView(binding.root)

        AppCompatDelegate.setDefaultNightMode(AppCompatDelegate.MODE_NIGHT_YES)

        // On first launch, start certificates manager first
        if (!certsManager.hasGeneratedCertificate && savedInstanceState == null)
            openCertsManager()
    }

    override fun onResume() {
        super.onResume()

        refreshInfo()
    }

    override fun onCreateOptionsMenu(menu: Menu?): Boolean {
        menuInflater.inflate(R.menu.main_activity_top_menu, menu)
        return super.onCreateOptionsMenu(menu)
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == R.id.open_settings) {
            openCertsManager()
            return true
        }

        return super.onOptionsItemSelected(item)
    }

    fun openCertsManager() {
        startActivity(Intent(this, CertsManager::class.java))
    }

    fun refreshInfo() {
        certsManager.aggregatedCertificate?.apply {
            binding.fullName.text = fullName.uppercase()
            binding.dateOfBirth.text = dateOfBirth

            val bitmap =
                BarcodeEncoder().encodeBitmap(encoded, BarcodeFormat.QR_CODE, qrSize, qrSize)
            binding.qrCode.setImageBitmap(bitmap)
        }

    }
}